// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 3, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; see the file COPYING.  If not, write to
// the Free Software Foundation, Inc., 51 Franklin Street, Fifth
// Floor, Boston, MA 02110-1301, USA.
#ifndef TUP_H
#define TUP_H

#include <QtGui>
#include <QTabWidget>
#include "ui_tup.h"
#include "tupsend.h"
#include "tupmachine.h"

class Tup : public QTabWidget, public Ui::Tup
{
  Q_OBJECT

  public:
  Tup(QTranslator *translator, QWidget *parent = 0);
  void connectUi(QTabWidget *tupUi);
  QString getVersion();

protected:
  void timerEvent(QTimerEvent *event); /**< timer for the paint event */
  void hideEvent(QHideEvent *event); /**< event occuring when the
					window is hidden */
  void showEvent(QShowEvent *event); /**< event occuring when the
					window is showed */

private:
  /// variables
  QTranslator *m_translator;
  int m_tupPaintTimerId;	     /**< id of the timer for the
					paint event */
  int m_tupSendTimerId;		/**< id of the timer for the sending
				   event */
  QMap<QString, QString> m_settings; /**< all the settings of the user */
  QString m_username;		     /**< name of the user */
  QString m_password;		/**< password of the user */
  QString m_machinename;	/**< name of the machine */
  QString m_version;		/**< version number of the client */
  QString m_agent;		/**< user agent of the client */
  int m_updatefreq;		/**< frequence of connections to the server */
  int m_updatefreqindex;	/**< index of the frequence item in
				   the combobox */
  int m_proxyUsed;		/**< Set to 1 if the proxy is used */
  QString m_proxyHostname;	/**< Host name of the proxy host */
  int m_proxyPort;		/**< Port of the proxy host */
  int m_proxyAuthUsed;		/**< Set to 1 if the proxy requires an
				   authentication */
  QString m_proxyUsername;	/**< Username used for the proxy */
  QString m_proxyPassword;	/**< Password used for the proxy */
  TupMachine *m_machine;	/**< machine informations */

  /// functions
  void displayUptime();		/**< displays the uptime on the window */
  // void displayVersion();
  void displaySysInfo();	/**< displays system informations on
				   the window */
  bool loadSettings();		/**< loads the user settings */
  void saveVariableSettings();	/**< saves the user settings to the map
				   m_settings */
  QStringList InitLanguages();

  QActionGroup *m_languageActionGroup;
private slots:
  void saveSettingsToFile();	/**< saves the user settings to a file  */
  void sendUptime();		/**< sends the uptime to the server */
  void switchLanguage();        /**< switches the language of the
				     application */
};

#endif // TUP_H
