// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 3, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; see the file COPYING.  If not, write to
// the Free Software Foundation, Inc., 51 Franklin Street, Fifth
// Floor, Boston, MA 02110-1301, USA.
#include "tupsend.h"

/**
 * Constructor.
 *
 * @param settings The application and user settings
 * @param machine Informations about the machine
 */
TupSend::TupSend(QMap<QString, QString> settings, TupMachine *machine)
{
  m_settings = settings;
  m_machine = machine;
}

/**
 * Constructor.
 *
 */
TupSend::TupSend()
{

}

/**
 * Destructor.
 *
 */
TupSend::~TupSend()
{

}

/**
 * Sends the uptime informations to the tup server.
 *
 */
void TupSend::sendInformations()
{
  QNetworkAccessManager *manager = new QNetworkAccessManager(this);
  connect(manager, SIGNAL(finished(QNetworkReply*)),
  	  this, SLOT(replyFinished(QNetworkReply*)));
  /// Proxy management
  if (m_settings.find("proxyused") != m_settings.end() &&
      m_settings.find("proxyused").value().toInt() == 1)
    {
      QNetworkProxy proxy;
      proxy = QNetworkProxy(QNetworkProxy::Socks5Proxy,
			    m_settings.find("proxyhostname").value(),
			    m_settings.find("proxyport").value().toUShort(),
			    m_settings.find("proxyusername").value(),
			    m_settings.find("proxypassword").value());
      manager->setProxy(proxy);
    }
  /// Http post request
  QNetworkRequest request;
  request.setUrl(QUrl("http://update.uptimeprj.com/update.php"));
  request.setRawHeader("User-Agent", "TUPQtClient alpha");
  QByteArray parameters = QByteArray();
  parameters.append("username=" + m_settings.find("username").value());
  parameters.append("&pass=" + m_settings.find("password").value());
  /// Use a format for the number of seconds. We don't want something
  /// like 1.99e+999
  parameters.append("&uptime="
		    + QString::number(m_machine->getUptime(), 'f', 0));
  parameters.append("&os=" + m_machine->getSysInfo());
  parameters.append("&mac=" + m_machine->getMd5MacAddress());
  parameters.append("&machine=" + m_settings.find("machinename").value());
  parameters.append("&distrib=" + m_machine->getSysInfoDistribution());
  // TODO
  // parameters.append("&cnb=2");
  // parameters.append("&distribcontent=NS4wLjQK");
  /// Request reply
  QNetworkReply *reply = manager->post(request, parameters);
  connect(reply, SIGNAL(error(QNetworkReply::NetworkError)),
  	  this, SLOT(slotError(QNetworkReply::NetworkError)));
}

/**
 * Deletes the reply object when the connection is finished.
 *
 * @param reply The reply to the request.
 */
void TupSend::replyFinished(QNetworkReply *reply)
{
  if (reply)
    {
      reply->deleteLater();
    }
}

/**
 * Indicates the network error encountered.
 *
 * @param error The network error.
 */
void TupSend::slotError(QNetworkReply::NetworkError error)
{
  /// TODO: exception management
  switch (error)
    {
    case QNetworkReply::NoError :
      qDebug() << "network OK";
      break;
    case QNetworkReply::ConnectionRefusedError :
      qDebug() << "connection refused";
      break;
    case QNetworkReply::TimeoutError:
      qDebug() << "time out";
    case QNetworkReply::HostNotFoundError:
      qDebug() << "host not found";
    default :
      qDebug() << error;
    }
}

